@@ -2,12 +2,11 @@
 
 import subprocess
 import sys
-import shlex
-
 import requests
+import colorama
 
 from ncurl.utils import join
-from .curl_utils import CurlUtils
+from ncurl.curl_utils import CurlUtils
 
 server_url = 'https://api.ncurl.sh/api'
 web_url = 'https://ncurl.sh/instants/'
@@ -30,10 +29,11 @@ def do_curl():
         "contents": upload_contents
     })
     response_str = result.content.decode("utf-8")
+    colorama.init()
     if result.status_code == 200:
-        print(f'\nView and share in: {web_url}?id=/{response_str}')
+        print(f'\n {colorama.Fore.GREEN}View and share in: {web_url}?id={response_str}')
     else:
-        print(f'Failed upload to server: {response_str}')
+        print(f'\n {colorama.Fore.RED}Failed upload to server: {response_str}')
         sys.exit(1)
 
 
